Module external_manifest

Module external_manifest 

Trait for external manifest handler.

This trait abstracts an external storage with put_if_not_exists semantics.

Structs

ExternalManifestCommitHandler
External manifest commit handler This handler is used to commit a manifest to an external store for detailed design, see https://github.com/lance-format/lance/issues/1183

Enums

Reservation
Outcome of ExternalManifestStore::put_if_predecessor.

Traits

ExternalManifestStore
External manifest store

Functions

finalize_staged
Copy staging_path to the canonical manifest path for version, point the store’s record at it, and drop the staging object.