pub fn list_detached_manifests<'a>(
base_path: &Path,
object_store: &'a dyn OSObjectStore,
) -> impl Stream<Item = Result<ManifestLocation>> + 'aExpand description
List all detached manifest files in the versions directory.
pub fn list_detached_manifests<'a>(
base_path: &Path,
object_store: &'a dyn OSObjectStore,
) -> impl Stream<Item = Result<ManifestLocation>> + 'aList all detached manifest files in the versions directory.