pub struct FragReuseIndex {
pub uuid: Uuid,
pub row_id_maps: Vec<HashMap<u64, Option<u64>>>,
pub details: FragReuseIndexDetails,
}Expand description
An index that stores row ID maps. A row ID map describes the mapping from old row address to new address after compactions. Each version contains the mapping for one round of compaction.
Fields
uuid: Uuidrow_id_maps: Vec<HashMap<u64, Option<u64>>>details: FragReuseIndexDetailsImplementations
Sourceimpl FragReuseIndex
impl FragReuseIndex
pub fn new( uuid: Uuid, row_id_maps: Vec<HashMap<u64, Option<u64>>>, details: FragReuseIndexDetails, ) -> Self
pub fn remap_row_id(&self, row_id: u64) -> Option<u64>
pub fn remap_row_addrs_tree_map( &self, row_addrs: &RowAddrTreeMap, ) -> RowAddrTreeMap
pub fn remap_row_ids_roaring_tree_map( &self, row_ids: &RoaringTreemap, ) -> RoaringTreemap
Sourcepub fn remap_row_ids_record_batch(
&self,
batch: RecordBatch,
row_id_idx: usize,
) -> Result<RecordBatch>
pub fn remap_row_ids_record_batch( &self, batch: RecordBatch, row_id_idx: usize, ) -> Result<RecordBatch>
Remap a record batch that contains a row_id column at index row_id_idx
Currently this assumes there are only 2 columns in the schema,
which is the case for all indexes.
For example, for btree, the schema is (value, row_id).
For vector index storage, the schema is (row_id, vector).
pub fn remap_row_ids_array(&self, array: ArrayRef) -> PrimitiveArray<UInt64Type>
pub fn remap_fragment_bitmap( &self, fragment_bitmap: &mut RoaringBitmap, ) -> Result<()>