pub struct IndexCatchupProgress {
pub index_name: String,
pub caught_up_generations: Vec<MergedGeneration>,
}Expand description
Tracks which merged generation a base table index has been rebuilt to cover. Used to determine whether to read from flushed MemTable indexes or base table.
Fields
index_name: Stringcaught_up_generations: Vec<MergedGeneration>Implementations
Sourceimpl IndexCatchupProgress
impl IndexCatchupProgress
pub fn new( index_name: String, caught_up_generations: Vec<MergedGeneration>, ) -> Self
Sourcepub fn caught_up_generation_for_shard(&self, shard_id: &Uuid) -> Option<u64>
pub fn caught_up_generation_for_shard(&self, shard_id: &Uuid) -> Option<u64>
Get the caught up generation for a specific shard. Returns None if the shard is not present (assumed fully caught up).