pub struct MemWalIndex {
pub details: MemWalIndexDetails,
}Expand description
MemWAL Index provides access to MemWAL configuration and state.
Fields
details: MemWalIndexDetailsImplementations
Sourceimpl MemWalIndex
impl MemWalIndex
pub fn new(details: MemWalIndexDetails) -> Self
pub fn merged_generation_for_shard(&self, shard_id: &Uuid) -> Option<u64>
Sourcepub fn index_caught_up_generation(
&self,
index_name: &str,
shard_id: &Uuid,
) -> Option<u64>
pub fn index_caught_up_generation( &self, index_name: &str, shard_id: &Uuid, ) -> Option<u64>
Get the caught up generation for a specific index and shard. Returns None if the index is not tracked (assumed fully caught up).
Sourcepub fn is_index_caught_up(&self, index_name: &str, shard_id: &Uuid) -> bool
pub fn is_index_caught_up(&self, index_name: &str, shard_id: &Uuid) -> bool
Check if an index is fully caught up for a shard. Returns true if the index covers all merged data for the shard.