pub enum UpdateMode {
RewriteRows,
RewriteColumns,
}Variants
RewriteRows
rows are deleted in current fragments and rewritten in new fragments. This is most optimal when the majority of columns are being rewritten or only a few rows are being updated.
RewriteColumns
within each fragment, columns are fully rewritten and inserted as new data files. Old versions of columns are tombstoned. This is most optimal when most rows are affected but a small subset of columns are affected.