pub struct DataOverlayGroup {
pub fragment_id: u64,
pub overlays: Vec<DataOverlayFile>,
}Expand description
Overlay files to append to a single fragment, in order (the last entry is
newest). The overlays are appended to the fragment’s existing overlays
list rather than replacing it, so overlays written by concurrent commits are
preserved. Each overlay’s committed_version is stamped to the new dataset
version at commit time (re-stamped on retry).
Fields
fragment_id: u64overlays: Vec<DataOverlayFile>Trait Implementations
Sourceimpl Clone for DataOverlayGroup
impl Clone for DataOverlayGroup
Sourcefn clone(&self) -> DataOverlayGroup
fn clone(&self) -> DataOverlayGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataOverlayGroup
impl Debug for DataOverlayGroup
Sourceimpl DeepSizeOf for DataOverlayGroup
impl DeepSizeOf for DataOverlayGroup
fn deep_size_of_children(&self, __context: &mut Context) -> usize
fn deep_size_of(&self) -> usize
Sourceimpl From<&DataOverlayGroup> for DataOverlayGroup
impl From<&DataOverlayGroup> for DataOverlayGroup
Sourcefn from(group: &DataOverlayGroup) -> Self
fn from(group: &DataOverlayGroup) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for DataOverlayGroup
impl PartialEq for DataOverlayGroup
impl StructuralPartialEq for DataOverlayGroup
Sourceimpl TryFrom<DataOverlayGroup> for DataOverlayGroup
impl TryFrom<DataOverlayGroup> for DataOverlayGroup