pub struct UpdateMap {
pub update_entries: Vec<UpdateMapEntry>,
pub replace: bool,
}Expand description
Represents updates to a map (either incremental or replacement)
Fields
update_entries: Vec<UpdateMapEntry>replace: boolIf true, the map will be replaced entirely with the new entries. If false, the new entries will be merged with the existing map.