merge_streams

Function merge_streams 

pub fn merge_streams(streams: Vec<ReadBatchTaskStream>) -> ReadBatchTaskStream
Given multiple streams of batch tasks, merge them into a single stream

This pulls one batch from each stream and then combines the columns from all of the batches into a single batch. The order of the batches in the streams is maintained and the merged batch columns will be in order from first to last stream. If the streams use different batch boundaries then batches are sliced so each merged output remains row-aligned.

This stream ends as soon as any of the input streams ends (we do not verify that the other input streams are finished as well)