Module format

Module format 

Re-exports

pub use crate::rowids::version::RowDatasetVersionMeta;
pub use crate::rowids::version::RowDatasetVersionRun;
pub use crate::rowids::version::RowDatasetVersionSequence;

Modules

pb
Protobuf definitions for Lance Format

Structs

BasePath
DataFile
Lance Data File
DataStorageFormat
DeletionFile
ExternalFile
A reference to a part of a file.
Fragment
Data fragment.
IndexFile
Metadata about a single file within an index segment.
IndexMetadata
Index metadata
Manifest
Manifest of a dataset
Transaction
WriterVersion

Enums

DeletionFileType
RowIdMeta
Metadata about location of the row id sequence.

Constants

DETACHED_VERSION_MASK
MAGIC
MAJOR_VERSION
These version/magic values are written at the end of manifest files (e.g. versions/1.version)
MINOR_VERSION

Traits

SelfDescribingFileReader

Functions

is_detached_version
list_index_files_with_sizes
List all files in an index directory with their sizes.

Type Aliases

IndexDeprecated