pub trait SelfDescribingFileReader {
// Required method
fn try_new_self_described_from_reader<'life0, 'async_trait>(
reader: Arc<dyn Reader>,
cache: Option<&'life0 LanceCache>,
) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'async_trait>>
where Self: Sized + 'async_trait,
'life0: 'async_trait;
// Provided method
fn try_new_self_described<'life0, 'life1, 'life2, 'async_trait>(
object_store: &'life0 ObjectStore,
path: &'life1 Path,
cache: Option<&'life2 LanceCache>,
) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'async_trait>>
where Self: Sized + Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait { ... }
}Required Methods
fn try_new_self_described_from_reader<'life0, 'async_trait>(
reader: Arc<dyn Reader>,
cache: Option<&'life0 LanceCache>,
) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'async_trait>>where
Self: Sized + 'async_trait,
'life0: 'async_trait,
Provided Methods
Sourcefn try_new_self_described<'life0, 'life1, 'life2, 'async_trait>(
object_store: &'life0 ObjectStore,
path: &'life1 Path,
cache: Option<&'life2 LanceCache>,
) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'async_trait>>
fn try_new_self_described<'life0, 'life1, 'life2, 'async_trait>( object_store: &'life0 ObjectStore, path: &'life1 Path, cache: Option<&'life2 LanceCache>, ) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'async_trait>>
Open a file reader without any cached schema
In this case the schema will first need to be loaded from the file itself.
When loading files from a dataset it is preferable to use the fragment reader to avoid this overhead.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".