Trait for external manifest handler.
This trait abstracts an external storage with put_if_not_exists semantics.
Structs
- External
Manifest Commit Handler - External manifest commit handler This handler is used to commit a manifest to an external store for detailed design, see https://github.com/lance-format/lance/issues/1183
Enums
Traits
- External
Manifest Store - External manifest store
Functions
- finalize_
staged - Copy
staging_pathto the canonical manifest path forversion, point the store’s record at it, and drop the staging object.